from ethiocalendar import *
import datetime as dt
# t = date.today()
# b = date(4,1,1)
# print(date(2019, 13, 6))
# print(datetime.now())
# print(t)
# print(date.fromordinal(100))
# print(date.fromtimestamp(1398928273.0526574))
# print(t.toordinal())
# print(b.toordinal())
# print(date.fromisoformat("2014-05-03"))
# print(date.fromisocalendar(2014, 1, 1))
# print(t.ctime())
# print(date.fromordinal(1).ctime())
# print(t.strftime("%Y"))
# print(t.strftime("%m"))
# print(t.strftime("%d"))
# print(t.strftime("%H:%M:%S"))
# print(t.strftime("%m-%d-%Y"))
# print(t.strftime("%m/%d/%Y"))
# print(t.strftime("%Y-%m-%d"))
# print(t.isoformat())
# print(t.year, t.month, t.day, t.timetuple(), t.toordinal())
# print(t.replace(month=11))
# print(t.weekday(), t.isoweekday())
# print(t.isocalendar())
# x = datetime.now()
# # print(datetime.fromtimestamp(datetime().now().timestamp()))
# print(datetime.utcnow())
# print(datetime.combine(t, time()))
# print(x.timestamp())
# print(x.timetz())
# print(x.ctime())
# print(x.isoformat())
# print(date(1994,3,20).ctime())
# print(date(1989,2,23).ctime())
# print(t.togregorian())
z = dt.datetime.now()
print(z)
print(fromgretoethio(z))
# print(x)